# @jupyterlab/testutils

Utilities for writing tests that use JupyterLab packages.

Includes utilities for converting signals and animation frame to promises,
creating document contexts and client sessions, and interacting with dialogs.
